ZeytinXContactModel class

Constructors

ZeytinXContactModel({required String name, String? phoneNumber, String? email})
ZeytinXContactModel.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
phoneNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited