ZeytinXFileModel class

Constructors

ZeytinXFileModel({required String url, required ZeytinXFileType type, Map<String, dynamic> moreData = const {}})
ZeytinXFileModel.empty()
factory
ZeytinXFileModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
moreData Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ZeytinXFileType
final
url String
final

Methods

copyWith({String? url, ZeytinXFileType? type, Map<String, dynamic>? moreData}) ZeytinXFileModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited