ZeytinXStore class

Constructors

ZeytinXStore(ZeytinStorage zeytin)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zeytin → ZeytinStorage
final

Methods

createStore({required ZeytinXStoreModel storeModel}) Future<ZeytinXResponse>
deleteStore({required String id}) Future<ZeytinXResponse>
getAllStores() Future<List<ZeytinXStoreModel>>
getStore({required String id}) Future<ZeytinXStoreModel>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateStore({required String id, required ZeytinXStoreModel storeModel}) Future<ZeytinXResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited