ZeytinXValue class

Constructors

ZeytinXValue(String box, String tag, Map<String, dynamic>? value)
ZeytinXValue.fromMap(Map<String, dynamic> map)
factory

Properties

box → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
final
value → Map<String, dynamic>?
final

Methods

copyWith({String? box, String? tag, Map<String, dynamic>? value}) → ZeytinXValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited