ZeytinXMessageStatusInfoModel class
Constructors
-
ZeytinXMessageStatusInfoModel({List<
String> ? deliveredTo, List<String> ? readBy, DateTime? deliveredAt, DateTime? readAt}) -
ZeytinXMessageStatusInfoModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deliveredAt → DateTime?
-
final
-
deliveredTo
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- readAt → DateTime?
-
final
-
readBy
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< String> ? deliveredTo, List<String> ? readBy, DateTime? deliveredAt, DateTime? readAt}) → ZeytinXMessageStatusInfoModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited