ZeytinXSocialCommentsModel class
Constructors
-
ZeytinXSocialCommentsModel({ZeytinXUserModel? user, String? text, List<
String> ? likes, String? postID, String? id, Map<String, dynamic> ? moreData}) -
ZeytinXSocialCommentsModel.fromJson(Map<
String, dynamic> data) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
-
likes
→ List<
String> ? -
final
-
moreData
→ Map<
String, dynamic> ? -
final
- postID → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- user → ZeytinXUserModel?
-
final
Methods
-
copyWith(
{ZeytinXUserModel? user, String? text, List< String> ? likes, String? postID, String? id, Map<String, dynamic> ? moreData}) → ZeytinXSocialCommentsModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited