ZeytinXStoreModel class
Constructors
-
ZeytinXStoreModel({required String id, required String name, required String description, required List<ZeytinXUserModel> owners, String logoUrl = '', String coverUrl = '', String email = '', String phoneNumber = '', String address = '', String website = '', double rating = 0.0, int followerCount = 0, bool isVerified = false, DateTime? createdAt, Map<String, dynamic> moreData = const {}})
-
-
ZeytinXStoreModel.empty()
-
factory
-
ZeytinXStoreModel.fromJson(Map<String, dynamic> data)
-
factory
Methods
-
copyWith({String? id, String? name, String? description, String? logoUrl, String? coverUrl, List<ZeytinXUserModel>? owners, String? email, String? phoneNumber, String? address, String? website, double? rating, int? followerCount, bool? isVerified, DateTime? createdAt, Map<String, dynamic>? moreData})
→ ZeytinXStoreModel
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
-
toString()
→ String
-
A string representation of this object.
inherited